EXPORTS
	__24CObexServerSendOperationG4TUidR15CMsvServerEntryiiR14TRequestStatus @ 1 NONAME ; CObexServerSendOperation::CObexServerSendOperation(TUid, CMsvServerEntry &, int, int, TRequestStatus &)
	CommandExpected__11CObexSrvMtm @ 2 NONAME ; CObexSrvMtm::CommandExpected(void)
	ConstructL__11CObexSrvMtm @ 3 NONAME ; CObexSrvMtm::ConstructL(void)
	ConstructL__24CObexServerSendOperationPC7TDesC16 @ 4 NONAME ; CObexServerSendOperation::ConstructL(TDesC16 const *)
	CopyFromLocalL__11CObexSrvMtmRC18CMsvEntrySelectionlR14TRequestStatus @ 5 NONAME ; CObexSrvMtm::CopyFromLocalL(CMsvEntrySelection const &, long, TRequestStatus &)
	CopyToLocalL__11CObexSrvMtmRC18CMsvEntrySelectionlR14TRequestStatus @ 6 NONAME ; CObexSrvMtm::CopyToLocalL(CMsvEntrySelection const &, long, TRequestStatus &)
	CopyWithinServiceL__11CObexSrvMtmRC18CMsvEntrySelectionlR14TRequestStatus @ 7 NONAME ; CObexSrvMtm::CopyWithinServiceL(CMsvEntrySelection const &, long, TRequestStatus &)
	CreateL__11CObexSrvMtmG9TMsvEntryR14TRequestStatus @ 8 NONAME ; CObexSrvMtm::CreateL(TMsvEntry, TRequestStatus &)
	DeleteAllL__11CObexSrvMtmRC18CMsvEntrySelectionR14TRequestStatus @ 9 NONAME ; CObexSrvMtm::DeleteAllL(CMsvEntrySelection const &, TRequestStatus &)
	DeleteL__11CObexSrvMtmRC18CMsvEntrySelectionR14TRequestStatus @ 10 NONAME ; CObexSrvMtm::DeleteL(CMsvEntrySelection const &, TRequestStatus &)
	DoCancel__11CObexSrvMtm @ 11 NONAME ; CObexSrvMtm::DoCancel(void)
	DoCancel__24CObexServerSendOperation @ 12 NONAME ; CObexServerSendOperation::DoCancel(void)
	DoComplete__11CObexSrvMtmi @ 13 NONAME ; CObexSrvMtm::DoComplete(int)
	DoRunL__11CObexSrvMtm @ 14 NONAME ; CObexSrvMtm::DoRunL(void)
	GetUserPasswordL__24CObexServerSendOperationRC7TDesC16 @ 15 NONAME ; CObexServerSendOperation::GetUserPasswordL(TDesC16 const &)
	MoveFromLocalL__11CObexSrvMtmRC18CMsvEntrySelectionlR14TRequestStatus @ 16 NONAME ; CObexSrvMtm::MoveFromLocalL(CMsvEntrySelection const &, long, TRequestStatus &)
	MoveToLocalL__11CObexSrvMtmRC18CMsvEntrySelectionlR14TRequestStatus @ 17 NONAME ; CObexSrvMtm::MoveToLocalL(CMsvEntrySelection const &, long, TRequestStatus &)
	MoveWithinServiceL__11CObexSrvMtmRC18CMsvEntrySelectionlR14TRequestStatus @ 18 NONAME ; CObexSrvMtm::MoveWithinServiceL(CMsvEntrySelection const &, long, TRequestStatus &)
	ProgressL__24CObexServerSendOperation @ 19 NONAME ; CObexServerSendOperation::ProgressL(void)
	Progress__11CObexSrvMtm @ 20 NONAME ; CObexSrvMtm::Progress(void)
	RunL__24CObexServerSendOperation @ 21 NONAME ; CObexServerSendOperation::RunL(void)
	SetInitialEntry__11CObexSrvMtmP15CMsvServerEntry @ 22 NONAME ; CObexSrvMtm::SetInitialEntry(CMsvServerEntry *)
	"_._11CObexSrvMtm" @ 23 NONAME ; CObexSrvMtm::~CObexSrvMtm(void)
	"_._24CObexServerSendOperation" @ 24 NONAME ; CObexServerSendOperation::~CObexServerSendOperation(void)
	__11CObexSrvMtmR17CRegisteredMtmDllP15CMsvServerEntry @ 25 NONAME ; CObexSrvMtm::CObexSrvMtm(CRegisteredMtmDll &, CMsvServerEntry *)
	ChangeL__11CObexSrvMtmG9TMsvEntryR14TRequestStatus @ 26 NONAME ; CObexSrvMtm::ChangeL(TMsvEntry, TRequestStatus &)
	SecondPhaseObexClientInitL__24CObexServerSendOperation @ 27 NONAME R3UNUSED ; CObexServerSendOperation::SecondPhaseObexClientInitL(void)
	__24CObexServerSendOperationG4TUidR15CMsvServerEntryiiR14TRequestStatusi @ 28 NONAME ; CObexServerSendOperation::CObexServerSendOperation(TUid, CMsvServerEntry &, int, int, TRequestStatus &, int)
	CompletingObserver__24CObexServerSendOperationi @ 29 NONAME R3UNUSED ; CObexServerSendOperation::CompletingObserver(int)

